==================
``psyclone.psyad``
==================

.. automodule:: psyclone.psyad

   .. contents::
      :local:


Submodules
==========

.. toctree::

   psyclone.psyad.adjoint_visitor
   psyclone.psyad.main
   psyclone.psyad.tl2ad
   psyclone.psyad.transformations
   psyclone.psyad.utils

.. currentmodule:: psyclone.psyad
